##  Global Permissions
The Global Fact Sheet Configuration section contains permissions for fact sheet attributes that are not considered fields, such as comments, resources, quality seal, and more.
